==> haskell-hspec-2.7.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec
version: 2.7.1
id: hspec-2.7.1-8yjc0CSgjCu2CF6Sl8z1Db
key: hspec-2.7.1-8yjc0CSgjCu2CF6Sl8z1Db
license: MIT
copyright: (c) 2011-2019 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:
    .
    * a friendly DSL for defining tests
    .
    * integration with QuickCheck, SmallCheck, and HUnit
    .
    * parallel test execution
    .
    * automatic discovery of test files
    .
    The Hspec Manual is at <http://hspec.github.io/>.
category: Testing
abi: 4000afdad5e277941c8435000a0b64cf
exposed: True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner
hidden-modules: Paths_hspec
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-2.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-2.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-2.7.1
hs-libraries: HShspec-2.7.1-8yjc0CSgjCu2CF6Sl8z1Db
depends:
    QuickCheck-2.13.2-KEVEjFnAQhp2P6vBjviJXi base-4.12.0.0
    hspec-core-2.7.1-GAgVZAe5BD33FzKgl8b1M
    hspec-discover-2.7.1-LGJDqSQ2jlrBzGstAgoI3G
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
haddock-interfaces: /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html: /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-2.7.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec
version: 2.7.1
id: hspec-2.7.1-2ie8rFQemXtK3qtKDBhHSi
key: hspec-2.7.1-2ie8rFQemXtK3qtKDBhHSi
license: MIT
copyright: (c) 2011-2019 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:
    .
    * a friendly DSL for defining tests
    .
    * integration with QuickCheck, SmallCheck, and HUnit
    .
    * parallel test execution
    .
    * automatic discovery of test files
    .
    The Hspec Manual is at <http://hspec.github.io/>.
category: Testing
abi: 18678bc8e7b9f89ef4a7c244c99a803c
exposed: True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner
hidden-modules: Paths_hspec
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-2.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-2.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-2.7.1
hs-libraries: HShspec-2.7.1-2ie8rFQemXtK3qtKDBhHSi
depends:
    QuickCheck-2.13.2-2FrYL0Zx0JL1157x99MUYA base-4.12.0.0
    hspec-core-2.7.1-7PyH3p27v7x451fZR38b3Y
    hspec-discover-2.7.1-FiDvOpHbj5848m5NCuFKmS
    hspec-expectations-0.8.2-9JgK0FgjaFj1ZSi2zSJcvx
haddock-interfaces: /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html: /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
